@@ -19,15 +19,14 @@
 
 activities <- function(eventlog) {
 	stop_eventlog(eventlog)
-	colnames(eventlog)[colnames(eventlog) == activity_id(eventlog)] <- "event_classifier"
 	colnames(eventlog)[colnames(eventlog) == activity_instance_id(eventlog)] <- "activity_instance_classifier"
 
 	output <- eventlog %>%
-		group_by_("event_classifier") %>%
+		group_by_(activity_id(eventlog)) %>%
 		summarize("absolute_frequency" = n_distinct(activity_instance_classifier)) %>%
-		arrange(-absolute_frequency)
-	output$relative_frequency <- output$absolute_frequency/sum(output$absolute_frequency)
+		arrange(-absolute_frequency) %>%
+		mutate(relative_frequency = absolute_frequency/sum(absolute_frequency)) %>%
+		arrange(-relative_frequency)
 
-	colnames(output)[colnames(output)== "event_classifier"] <- activity_id(eventlog)
 	return(output)
 }
