@@ -20,15 +20,11 @@
 activity_presence <- function(eventlog) {
 	stop_eventlog(eventlog)
 
-	event_classifier <- activity_id(eventlog)
-	case_classifier <- case_id(eventlog)
-	colnames(eventlog)[colnames(eventlog)==case_id(eventlog)] <- "case_classifier"
-
 	r <- eventlog %>%
-		group_by_(event_classifier, "case_classifier") %>%
+		group_by_(activity_id(eventlog), case_id(eventlog)) %>%
 		summarize() %>%
-		summarize("absolute" = n_distinct(case_classifier)) %>%
+		summarize("absolute" = n()) %>%
 		mutate(relative = absolute/n_cases(eventlog)) %>%
-		arrange(desc(absolute))
+		arrange(-absolute)
 	return(r)
 }
