@@ -17,6 +17,8 @@
 #'
 #' @param reverse A logical parameter depicting whether the selection should be reversed.
 #'
+#' @param units The time unit used for filtering.
+
 #'
 #' @export filter_throughput_time
 #'
@@ -25,7 +27,8 @@ filter_throughput_time <- function(eventlog,
 								   lower_threshold = NULL,
 								   upper_threshold = NULL,
 								   percentile_cut_off = NULL,
-								   reverse = F) {
+								   reverse = F,
+								   units = "days") {
 
 	stop_eventlog(eventlog)
 
@@ -45,5 +48,6 @@ filter_throughput_time <- function(eventlog,
 		return(filter_throughput_time_threshold(eventlog,
 												lower_threshold = lower_threshold,
 												upper_threshold = upper_threshold,
-												reverse = reverse))
+												reverse = reverse,
+												units = units))
 }
